@@ -3,9 +3,9 @@ use strict;
 use warnings;
 
 package Mxpress::PDF {
-	our $VERSION = '0.06';
+	our $VERSION = '0.07';
 	use Zydeco (
-		version	=> '0.06',
+		version	=> '0.07',
 		authority => 'cpan:LNATION',
 	);
 	use Colouring::In;
@@ -302,6 +302,7 @@ package Mxpress::PDF {
 				if ($page->columns > 1 && !$self->full) {
 					$w = ($page->w / $page->columns);
 					$x += ($w * ($page->column - 1));
+					$w -= $sp;
 				}
 				$w -= ($pp + $sp);
 				if ($page->rows > 1 && !$self->full) {
@@ -315,6 +316,7 @@ package Mxpress::PDF {
 						$h -= $pp;
 					}
 				}
+				$h -= $sp;
 			}
 			return $xy ? ($x, $y) : ($x, $y, $w, $h);
 		}
@@ -588,7 +590,6 @@ package Mxpress::PDF {
 							$ypos -= $l if @paragraph;
 						} elsif ($self->pad) {
 							my $pad_end = $self->pad_end;
-							$lw -= $self->page->padding/mm;
 							my $pad = sprintf ("%s%s",
 								$self->pad x int(((
 									(((($lw + $wordspace) - $line_width) - $text->advancewidth($self->pad . $pad_end)))
@@ -896,7 +897,7 @@ Mxpress::PDF - PDF
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
